%define api		1.0
%define bname		gstreamer%{api}

%define build_plf	0

%if "%{?distro_section}" == "tainted"
%define build_plf	1
%endif

%define build_amrnb	0
%define build_amrwbdec	0
%define build_x264	0

%if %build_plf
%define build_amrnb	1
%define build_amrwbdec	1
%define build_x264	1
%endif

# disabled as we don't have hotdoc
%bcond_with docs

Summary:	GStreamer Streaming-media framework plug-ins
Name:		%{bname}-plugins-ugly
Version:	1.18.5
Release:  %mkrel 1
License:	LGPLv2+
Group:		Sound/Utilities
Source:		https://gstreamer.freedesktop.org/src/gst-plugins-ugly/gst-plugins-ugly-%{version}.tar.xz
URL:		https://gstreamer.freedesktop.org/
#gw for the pixbuf plugin
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(orc-0.4)
BuildRequires:	pkgconfig(gstreamer-plugins-base-1.0) >= %{version}
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(mad)
BuildRequires:	pkgconfig(id3tag)
BuildRequires:	pkgconfig(dvdread)
BuildRequires:	pkgconfig(check)
BuildRequires:	meson

%ifarch %{valgrind_arches}
BuildRequires:	pkgconfig(valgrind)
%endif

Provides:	%{bname}-audiosrc
Provides:	%{bname}-audiosink

%description
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plug-ins.

This package contains a set of plug-ins that have good quality and
correct functionality, but distributing them might pose problems. The
license on either the plug-ins or the supporting libraries might not
be how the GStreamer authors like. The code might be widely known to
present patent problems.

%if %build_plf
This package is in the 'tainted' section as it violates some patents.
%endif

%prep
%setup -q -n gst-plugins-ugly-%{version}

%build
%meson \
%if ! %build_amrnb
	-Damrnb=disabled \
%endif
%if ! %build_amrwbdec
	-Damrwbdec=disabled \
%endif
%if ! %build_x264
	-Dx264=disabled \
%endif
	-Ddoc=%{?with_docs:enabled}%{?!with_docs:disabled} \
	-Dtests=disabled \
	-Dpackage-name='%{_vendor} %{name} package' \
	-Dpackage-origin='https://www.%{_real_vendor}.hu/'

%meson_build

%check
%meson_test

%install
%meson_install

%find_lang gst-plugins-ugly-%{api}

%files -f gst-plugins-ugly-%{api}.lang
%doc AUTHORS COPYING README NEWS
%{_libdir}/gstreamer-%{api}/libgstasf.so
%{_libdir}/gstreamer-%{api}/libgstdvdlpcmdec.so
%{_libdir}/gstreamer-%{api}/libgstdvdread.so
%{_libdir}/gstreamer-%{api}/libgstdvdsub.so
%{_libdir}/gstreamer-%{api}/libgstrealmedia.so
%{_libdir}/gstreamer-%{api}/libgstxingmux.so

%if %build_x264
%package -n %{bname}-x264
Summary:	GStreamer plug-in for H264/AVC video encoding
Group:		Video/Utilities
BuildRequires:	pkgconfig(x264)

%description -n %{bname}-x264
Plug-in for encoding H264/AVC video.

This package is in the 'tainted' section as it violates some patents.
%files -n %{bname}-x264
%{_libdir}/gstreamer-%{api}/libgstx264.so
%{_datadir}/gstreamer-%{api}/presets/GstX264Enc.prs
%endif

%if %build_amrnb
%package -n %{bname}-amrnb
Summary:	GStreamer plug-in for AMR-NB support
Group: 		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:	opencore-amr-devel

%description -n %{bname}-amrnb
Plug-in for decoding AMR-NB under GStreamer.

This package is in the 'tainted' section as it violates some patents.

%files -n %{bname}-amrnb
%{_libdir}/gstreamer-%{api}/libgstamrnb.so
%{_datadir}/gstreamer-%{api}/presets/GstAmrnbEnc.prs
%endif

%if %build_amrwbdec
%package -n %{bname}-amrwbdec
Summary:	GStreamer plug-in for AMR-WB decoding support
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:	opencore-amr-devel

%description -n %{bname}-amrwbdec
Plug-in for decoding AMR-Wb under GStreamer.

This package is in the 'tainted' section as it violates some patents.

%files -n %{bname}-amrwbdec
%{_libdir}/gstreamer-%{api}/libgstamrwbdec.so
%endif

### SIDPLAY ###
%package -n %{bname}-sid
Summary:	GStreamer Sid C64 music plugin
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:	sidplay-devel >= 1.36.0

%description -n %{bname}-sid
Plugin for playback of C64 SID format music files

%files -n %{bname}-sid
%{_libdir}/gstreamer-%{api}/libgstsid.so

### A52DEC ###
%package -n %{bname}-a52dec
Summary:	GStreamer AC-3 aka A/52 audio decoder plugin
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:	a52dec-devel >= 0.7.3

%description -n %{bname}-a52dec
Plugin for decoding of AC-3 (A/52) audio as often found on DVDs.

%files -n %{bname}-a52dec
%{_libdir}/gstreamer-%{api}/libgsta52dec.so

%package -n %{bname}-mpeg
Summary:	GStreamer plug-ins for MPEG video playback and encoding
Group:		Video/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:	libmpeg2dec-devel >= 0.3.1

%description -n %{bname}-mpeg
Plug-ins for playing and encoding MPEG video.

%files -n %{bname}-mpeg
%{_libdir}/gstreamer-%{api}/libgstmpeg2dec.so

%package -n %{bname}-cdio
Summary:	GStreamer plug-in for audio CD playback
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:	pkgconfig(libcdio)

%description -n %{bname}-cdio
Plug-in for audio CD playback.

%files -n %{bname}-cdio
%{_libdir}/gstreamer-%{api}/libgstcdio.so


%changelog
* Thu Jan 20 2022 Charles K. Barcza <info@blackpanther.hu> 1.18.5-1bP
- build package for blackPanther OS v22.x 32/64 bit or ARM
------------------------------------------------------------------------

* Sat Nov 21 2020 Charles K. Barcza <info@blackpanther.hu> 1.18.1-1bP
- build package for blackPanther OS v17-19.x 32/64 bit or ARM
------------------------------------------------------------------------

* Sat Oct 27 2018 Charles K. Barcza <info@blackpanther.hu> 1.14.4-1bP
- build package for blackPanther OS v17-19.x 32/64 bit or ARM
------------------------------------------------------------------------

* Wed Oct  3 2018 Charles K. Barcza <info@blackpanther.hu> 1.14.3-1bP
- build package for blackPanther OS v17-19.x 32/64 bit or ARM
------------------------------------------------------------------------

* Sun Sep  9 2018 Charles K. Barcza <info@blackpanther.hu> 1.14.2-1bP
- build package for blackPanther OS v16/17.x
------------------------------------------------------------------------
